@@ -14,7 +14,6 @@
 #include <kuiviewer_part_debug.h>
 #include "kuiviewer_version.h"
 // KF
-#include <kparts_version.h>
 #include <KActionCollection>
 #include <KSelectAction>
 #include <KConfig>
@@ -45,18 +44,10 @@ KUIViewerPart::KUIViewerPart(QWidget* parentWidget,
                              QObject* parent,
                              const KPluginMetaData& metaData,
                              const QVariantList& /*args*/)
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 240, 0)
     : KParts::ReadOnlyPart(parent, metaData)
-#else
-    : KParts::ReadOnlyPart(parent)
-#endif
     , m_subWindow(nullptr)
     , m_view(nullptr)
 {
-#if KPARTS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    setMetaData(metaData);
-#endif
-
     // this should be your custom internal widget
     m_widget = new QMdiArea(parentWidget);
     m_widget->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
@@ -75,7 +66,7 @@ KUIViewerPart::KUIViewerPart(QWidget* parentWidget,
     //m_style->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_S));
     m_style->setEditable(false);
 
-    m_styleFromConfig = KConfigGroup(KSharedConfig::openConfig(), "General").readEntry("currentWidgetStyle", QString());
+    m_styleFromConfig = KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("General")).readEntry("currentWidgetStyle", QString());
 
     const QStringList styles = QStyleFactory::keys();
     m_style->setItems(QStringList(i18nc("Default style", "Default")) + styles);
@@ -319,7 +310,7 @@ void KUIViewerPart::slotStyle(int)
     /* the style changed, update the configuration */
     if (m_styleFromConfig != styleName) {
         KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
-        KConfigGroup cg(cfg, "General");
+        KConfigGroup cg(cfg, QStringLiteral("General"));
         if (m_style->currentItem() > 0) {
             /* A style different from the default */
             cg.writeEntry("currentWidgetStyle", styleName);
